@@ -16,7 +16,7 @@ use Pod::Usage ();
 use Cwd 'abs_path';
 use Config;
 
-our $VERSION = '0.211';
+our $VERSION = '0.212';
 
 use constant WIN32 => $^O eq 'MSWin32';
 
@@ -56,6 +56,7 @@ sub parse_options {
         "r|resolver=s@" => \@resolver,
         "mirror-only" => \($self->{mirror_only}),
         "dev" => \($self->{dev}),
+        "man-pages" => \($self->{man_pages}),
     or exit 1;
 
     $self->{local_lib} = abs_path $self->{local_lib} unless $self->{global};
@@ -167,6 +168,7 @@ sub cmd_install {
         notest          => $self->{notest},
         sudo            => $self->{sudo},
         resolver        => $self->generate_resolver,
+        man_pages       => $self->{man_pages},
         ($self->{global} ? () : (local_lib => $self->{local_lib})),
     );
     my $pipes = Parallel::Pipes->new($self->{workers}, sub {
@@ -237,6 +239,9 @@ sub register_initial_job {
             my %ref = $arg =~ s/(?<=\.git)@(.+)$// ? (ref => $1) : ();
             my $dist = App::cpm::Distribution->new(source => "git", uri => $arg, provides => [], %ref);
             $master->add_distribution($dist);
+        } elsif ($arg =~ m{^https?://}) {
+            my $dist = App::cpm::Distribution->new(source => "http", uri => $arg, provides => []);
+            $master->add_distribution($dist);
         } else {
             my ($package, $version, $dev);
             # copy from Menlo
@@ -325,8 +330,8 @@ sub generate_resolver {
                 );
             } elsif ($klass =~ /^metacpan$/i) {
                 $resolver = App::cpm::Resolver::MetaCPAN->new(dev => $self->{dev});
-            } elsif ($klass =~ /^[0o]2packages?$/i) {
-                require App::cpm::Resolver::O2Packages;
+            } elsif ($klass =~ /^02packages?$/i) {
+                require App::cpm::Resolver::02Packages;
                 my ($path, $mirror);
                 if (@arg > 1) {
                     ($path, $mirror) = @arg;
@@ -335,7 +340,7 @@ sub generate_resolver {
                 } else {
                     $mirror = $self->{mirror}[0];
                 }
-                $resolver = App::cpm::Resolver::O2Packages->new(
+                $resolver = App::cpm::Resolver::02Packages->new(
                     $path ? (path => $path) : (),
                     mirror => $mirror,
                 );
@@ -354,8 +359,8 @@ sub generate_resolver {
     }
 
     if ($self->{mirror_only}) {
-        require App::cpm::Resolver::O2Packages;
-        $cascade->add(App::cpm::Resolver::O2Packages->new(mirror => $_)) for @{$self->{mirror}};
+        require App::cpm::Resolver::02Packages;
+        $cascade->add(App::cpm::Resolver::02Packages->new(mirror => $_)) for @{$self->{mirror}};
         return $cascade;
     }
 
