@@ -2,7 +2,7 @@ package App::cpm::Worker::Installer;
 use strict;
 use warnings;
 use utf8;
-our $VERSION = '0.211';
+our $VERSION = '0.212';
 
 use CPAN::DistnameInfo;
 use CPAN::Meta;
@@ -68,7 +68,7 @@ sub new {
         base => $menlo_base,
         log  => $menlo_build_log,
         quiet => 1,
-        pod2man => undef,
+        pod2man => $option{man_pages},
         notest => $option{notest},
         sudo => $option{sudo},
         mirrors => ["https://cpan.metacpan.org/"], # this is dummy
@@ -162,7 +162,7 @@ sub fetch {
                 last FETCH;
             } else {
                 local $self->menlo->{save_dists};
-                if ($CACHED_MIRROR->($uri)) {
+                if ($distfile and $CACHED_MIRROR->($uri)) {
                     my $cache = File::Spec->catfile($self->{cache}, "authors/id/$distfile");
                     if (-f $cache) {
                         File::Copy::copy($cache, $basename);
@@ -211,7 +211,7 @@ sub _get_configure_requirements {
         version => $p->{$_}{version} || undef,
     }, sort keys %$p];
 
-    if (!@$requirements && -f "Build.PL") {
+    if (!@$requirements && -f "Build.PL" && $distfile !~ m{/Module-Build-[0-9v]}) {
         push @$requirements, {
             package => "Module::Build", version => "0.38",
             phase => "configure", type => "requires",
